local FishWarden = FishWarden_79a6ca19_6666_4759_9b8f_a67708694e5b;

FishWarden.GUI.CustomHelpFrame = CreateFrame("Frame", "FishWardenCustomHelpPanel", UIParent);

local MainFrame = FishWarden.GUI.MainFrame;
local CustomHelpFrame = FishWarden.GUI.CustomHelpFrame;

function CustomHelpFrame:DoInit()
    CustomHelpFrame.name = CUSTOM .. " - " .. HELP_LABEL;
    CustomHelpFrame.parent = MainFrame.name;
    InterfaceOptions_AddCategory(CustomHelpFrame);
    CustomHelpFrame:SetScript("OnShow", CustomHelpFrame.ShowHandler);
    CustomHelpFrame:SetScript("OnMouseWheel", CustomHelpFrame.WheelHandler);
    CustomHelpFrame:EnableMouseWheel(true);

    CustomHelpFrame.iddTitle = CustomHelpFrame:CreateFontString("$parent_Title","ARTWORK","GameFontNormalLarge");
    CustomHelpFrame.iddTitle:SetPoint("TOPLEFT", CustomHelpFrame, "TOPLEFT", 13, -13);
    CustomHelpFrame.iddTitle:SetText(CustomHelpFrame.name);
    CustomHelpFrame.iddTitle:SetJustifyH("CENTER");

    CustomHelpFrame.iddNextBtn = CreateFrame("Button", nil, CustomHelpFrame, "UIPanelButtonTemplate");
    CustomHelpFrame.iddNextBtn:SetPoint("BOTTOM", CustomHelpFrame, "BOTTOM", 0, 8);
    CustomHelpFrame.iddNextBtn:SetPoint("LEFT", CustomHelpFrame, "CENTER", 2, 0);
    CustomHelpFrame.iddNextBtn:SetText(NEXT);
    CustomHelpFrame.iddNextBtn:SetScript("OnClick", CustomHelpFrame.OnClickNext);

    CustomHelpFrame.iddPrevBtn = CreateFrame("Button", nil, CustomHelpFrame, "UIPanelButtonTemplate");
    CustomHelpFrame.iddPrevBtn:SetPoint("TOPRIGHT", CustomHelpFrame.iddNextBtn, "TOPLEFT", -4, 0);
    CustomHelpFrame.iddPrevBtn:SetText(PREV);
    CustomHelpFrame.iddPrevBtn:SetScript("OnClick", CustomHelpFrame.OnClickPrev);

    CustomHelpFrame.iddHelp = {};

    CustomHelpFrame:AddTitle(GENERAL);
    CustomHelpFrame:AddHelp(format(FishWarden.Locale.HelpCustomMain, CUSTOM));
    CustomHelpFrame:AddHelp(format(FishWarden.Locale.HelpCustomShiftClick, CUSTOM));

    CustomHelpFrame:AddTitle(FishWarden.Locale.HelpCustomSpecialChars);
    CustomHelpFrame:AddHelp(":    " .. FishWarden.Locale.HelpCustomCharColon);
    CustomHelpFrame:AddHelp("#    " .. FishWarden.Locale.HelpCustomCharComment);
    CustomHelpFrame:AddHelp("=    " .. FishWarden.Locale.HelpCustomCharEquals);
    CustomHelpFrame:AddHelp("-    " .. FishWarden.Locale.HelpCustomCharHyphen);
    CustomHelpFrame:AddHelp("()    " .. FishWarden.Locale.HelpCustomCharParen);

    CustomHelpFrame:AddTitle(FishWarden.Locale.HelpCustomPrecedence);
    CustomHelpFrame:AddHelp(format(FishWarden.Locale.HelpCustomPrecedenceMatches, CUSTOM));
end

function CustomHelpFrame:AddTitle(name)
    local index = #CustomHelpFrame.iddHelp + 1;
    local newtitle = CustomHelpFrame:CreateFontString("$parent_title"..index,"ARTWORK","QuestTitleFont");
    newtitle:SetPoint("BOTTOM", CustomHelpFrame.iddNextBtn, "TOP", 0, 5);
    newtitle:SetJustifyH("CENTER");
    newtitle:SetJustifyV("TOP");
    newtitle:SetTextColor(0, 1, 1);
    newtitle:SetText(name);
    CustomHelpFrame.iddHelp[index] = newtitle;
end

function CustomHelpFrame:AddHelp(text)
    local index = #CustomHelpFrame.iddHelp + 1;
    local newhelp = CustomHelpFrame:CreateFontString("$parent_help"..index,"ARTWORK","QuestFontLeft");
    newhelp:SetPoint("BOTTOM", CustomHelpFrame.iddNextBtn, "TOP", 0, 5);
    newhelp:SetJustifyV("TOP");
    newhelp:SetTextColor(1, 1, 1);
    newhelp:SetText(text);
    CustomHelpFrame.iddHelp[index] = newhelp;
end

function CustomHelpFrame:ShowHandler()
    local maxwidth = CustomHelpFrame:GetWidth();
    if (maxwidth == 0) then maxwidth = 413; end

    CustomHelpFrame.iddTitle:SetWidth(maxwidth - 26);

    CustomHelpFrame.btnheight = max(CustomHelpFrame.iddNextBtn:GetTextHeight(), CustomHelpFrame.iddPrevBtn:GetTextHeight()) + 10;
    CustomHelpFrame.iddNextBtn:SetWidth(CustomHelpFrame.iddNextBtn:GetTextWidth() + 10);
    CustomHelpFrame.iddNextBtn:SetHeight(CustomHelpFrame.btnheight);
    CustomHelpFrame.iddPrevBtn:SetWidth(CustomHelpFrame.iddPrevBtn:GetTextWidth() + 10);
    CustomHelpFrame.iddPrevBtn:SetHeight(CustomHelpFrame.btnheight);

    for i, v in ipairs(CustomHelpFrame.iddHelp) do
        v:SetWidth(maxwidth - 26);
    end

    CustomHelpFrame.first = 0;
    CustomHelpFrame:OnClickNext();
end

function CustomHelpFrame:WheelHandler(delta)
    if (delta > 0) then CustomHelpFrame:OnClickPrev(); end;
    if (delta < 0) then CustomHelpFrame:OnClickNext(); end;
end

function CustomHelpFrame:OnClickPrev(button)
    if (not CustomHelpFrame.iddPrevBtn:IsEnabled()) then return; end

    local maxheight = CustomHelpFrame:GetHeight();
    if (maxheight <= 0) then maxheight = 428; end
    maxheight = maxheight - CustomHelpFrame.btnheight - 13;

    local first = CustomHelpFrame.first - 1;
    local last = first - 1;
    local curheight = CustomHelpFrame.iddTitle:GetHeight() + 13;
    local curhelp;

    repeat
        last = last + 1;
        curhelp = CustomHelpFrame.iddHelp[last];
        curheight = curheight + 8;
        curhelp:SetPoint("TOPLEFT", CustomHelpFrame, "TOPLEFT", 13, -curheight);
        curheight = curheight + curhelp:GetHeight();
        curhelp:Show();
    until (curheight >= maxheight or not CustomHelpFrame.iddHelp[last+1]);

    if (first == 1) then CustomHelpFrame.iddPrevBtn:Disable();
    else CustomHelpFrame.iddPrevBtn:Enable(); end

    if (curheight < maxheight) then CustomHelpFrame.iddNextBtn:Disable();
    else CustomHelpFrame.iddNextBtn:Enable(); end

    for i, v in ipairs(CustomHelpFrame.iddHelp) do
        if (i < first or i > last) then v:Hide(); end
    end

    CustomHelpFrame.first = first;
    CustomHelpFrame.last = last;
end

function CustomHelpFrame:OnClickNext(button)
    if (not CustomHelpFrame.iddNextBtn:IsEnabled() and CustomHelpFrame.first ~= 0) then return; end

    local maxheight = CustomHelpFrame:GetHeight();
    if (maxheight <= 0) then maxheight = 428; end
    maxheight = maxheight - CustomHelpFrame.btnheight - 13;

    local first = CustomHelpFrame.first + 1;
    local last = first - 1;
    local curheight = CustomHelpFrame.iddTitle:GetHeight() + 13;
    local curhelp;

    repeat
        last = last + 1;
        curhelp = CustomHelpFrame.iddHelp[last];
        curheight = curheight + 8;
        curhelp:SetPoint("TOPLEFT", CustomHelpFrame, "TOPLEFT", 13, -curheight);
        curheight = curheight + curhelp:GetHeight();
        curhelp:Show();
    until (curheight >= maxheight or not CustomHelpFrame.iddHelp[last+1]);

    if (first == 1) then CustomHelpFrame.iddPrevBtn:Disable();
    else CustomHelpFrame.iddPrevBtn:Enable(); end

    if (curheight < maxheight) then CustomHelpFrame.iddNextBtn:Disable();
    else CustomHelpFrame.iddNextBtn:Enable(); end

    for i, v in ipairs(CustomHelpFrame.iddHelp) do
        if (i < first or i > last) then v:Hide(); end
    end

    CustomHelpFrame.first = first;
    CustomHelpFrame.last = last;
end

